@@ -126,8 +126,8 @@ class RackspaceTests(unittest.TestCase):
 
     def test_test_alarm(self):
         entity = self.driver.list_entities()[0]
-        criteria = ('if (metric[\"code\"] == \"404\") { return CRITICAL, \"not',
-                   'found\" } return OK')
+        criteria = ('if (metric[\"code\"] == \"404\") { return CRITICAL, ',
+                   ' \"not found\" } return OK')
         check_data = []
         result = self.driver.test_alarm(entity=entity, criteria=criteria,
                                         check_data=check_data)
@@ -185,15 +185,17 @@ class RackspaceTests(unittest.TestCase):
         notification_plan.delete()
 
     def test_list_agent_tokens(self):
-      tokens = self.driver.list_agent_tokens()
-      fixture_tokens = json.loads(RackspaceMockHttp.fixtures.load('agent_tokens.json'))
-      first_token = fixture_tokens["values"][0]["token"]
-      self.assertEqual(tokens[0].token, first_token)
-      self.assertEqual(len(tokens), 11)
+        tokens = self.driver.list_agent_tokens()
+        fixture = RackspaceMockHttp.fixtures.load('agent_tokens.json')
+        fixture_tokens = json.loads(fixture)
+        first_token = fixture_tokens["values"][0]["token"]
+        self.assertEqual(tokens[0].token, first_token)
+        self.assertEqual(len(tokens), 11)
 
     def test_delete_agent_token(self):
         agent_token = self.driver.list_agent_tokens()[0]
-        self.assertTrue(self.driver.delete_agent_token(agent_token=agent_token))
+        self.assertTrue(self.driver.delete_agent_token(
+          agent_token=agent_token))
 
     def test_get_monitoring_zone(self):
         monitoring_zone = self.driver \
@@ -230,6 +232,33 @@ class RackspaceTests(unittest.TestCase):
             result = self.driver._url_to_obj_ids(url)
             self.assertEqual(result, expected)
 
+    def test_force_base_url(self):
+        RackspaceMonitoringDriver.connectionCls.conn_classes = (
+                RackspaceMockHttp, RackspaceMockHttp)
+        RackspaceMonitoringDriver.connectionCls.auth_url = \
+                'https://auth.api.example.com/v1.1/'
+
+        RackspaceMockHttp.type = None
+        driver = RackspaceMonitoringDriver(key=RACKSPACE_PARAMS[0],
+                                           secret=RACKSPACE_PARAMS[1],
+                ex_force_base_url='http://www.todo.com')
+        driver.list_entities()
+        self.assertEqual(driver.connection._ex_force_base_url,
+                         'http://www.todo.com/23213')
+
+    def test_force_base_url_is_none(self):
+        RackspaceMonitoringDriver.connectionCls.conn_classes = (
+                RackspaceMockHttp, RackspaceMockHttp)
+        RackspaceMonitoringDriver.connectionCls.auth_url = \
+                'https://auth.api.example.com/v1.1/'
+
+        RackspaceMockHttp.type = None
+        driver = RackspaceMonitoringDriver(key=RACKSPACE_PARAMS[0],
+                                           secret=RACKSPACE_PARAMS[1])
+        driver.list_entities()
+        self.assertEqual(driver.connection._ex_force_base_url,
+                        'https://monitoring.api.rackspacecloud.com/v1.0/23213')
+
 
 class RackspaceMockHttp(MockHttpTestCase):
     auth_fixtures = MonitoringFileFixtures('rackspace/auth')
@@ -372,7 +401,7 @@ class RackspaceMockHttp(MockHttpTestCase):
         raise NotImplementedError('')
 
     def _23213_agent_tokens_at28OJNsRB(self, method, url, body, headers):
-      if method == 'DELETE':
+        if method == 'DELETE':
             body = ''
             return (httplib.NO_CONTENT, body, self.json_content_headers,
                     httplib.responses[httplib.NO_CONTENT])
